@@ -7,7 +7,7 @@ from dataclasses import dataclass
 from pathlib import Path
 from typing import Dict, List, Optional
 
-from ycontract import prev_contract
+from ycontract import in_contract
 
 from exclock.sound_player import Player
 from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
@@ -42,20 +42,20 @@ class Sound:
     def __post_init__(self) -> None:
         self.sound_filename = get_real_sound_filename(self.sound_filename)
 
-    @prev_contract(lambda self: Path(self.sound_filename).exists())
+    @in_contract(lambda self: Path(self.sound_filename).exists())
     def play(self):
         p = Player(self.sound_filename)
         p.play()
 
     @classmethod
-    @prev_contract(lambda json: "message" in json and "sound_filename" in json)
+    @in_contract(lambda json: "message" in json and "sound_filename" in json)
     def from_dict(cls, json: dict) -> Sound:
         return Sound(
             message=json["message"],
             sound_filename=get_real_sound_filename(json.get("sound_filename")),
         )
 
-    @prev_contract(lambda self, other: isinstance(other, self.__class__))
+    @in_contract(lambda self, other: isinstance(other, self.__class__))
     def __eq__(self, other) -> bool:
         return self.message == other.message and self.sound_filename == other.sound_filename
 
@@ -70,7 +70,7 @@ class ClockTimer:
     def sorted_sounds(self) -> Dict[int, Sound]:
         return {sec: self.sounds[sec] for sec in sorted(self.sounds)}
 
-    @prev_contract(lambda count: count >= 0)
+    @in_contract(lambda count: count >= 0)
     def run_once(self, count: int) -> None:
         sounds = self.sorted_sounds
 
@@ -100,8 +100,11 @@ class ClockTimer:
                 count += 1
 
     @classmethod
-    @prev_contract(lambda json: "sounds" in json)
-    @prev_contract(lambda json: isinstance(json, dict))
+    @in_contract(
+        lambda json: isinstance(json, dict),
+        lambda json: "sounds" in json,
+    )
+    @in_contract(lambda json: isinstance(json, dict))
     def from_dict(cls, json: dict) -> ClockTimer:
         sounds = {}
         for sec, sound in json["sounds"].items():
