@@ -6,7 +6,7 @@ from pathlib import Path
 from subprocess import DEVNULL, Popen
 from typing import List
 
-from ycontract import prev_contract
+from ycontract import in_contract
 
 
 @dataclass
@@ -17,7 +17,7 @@ class Player:
     _proc: Popen = Popen("echo", stdout=DEVNULL, stderr=DEVNULL)
 
     @property  # type: ignore
-    @prev_contract(lambda self: Path(self.sound_filename).exists())
+    @in_contract(lambda self: Path(self.sound_filename).exists())
     def play_commands(self) -> List[str]:
         commands = ["mplayer", self.sound_filename]
         return commands
